import isArray from 'isarray'
import { arrayReduce } from 'fast-loops'
import { parseEdges, wrapKey } from '../../core/utils'
import { COLOR, EDGES } from '../../core/constants'

export default ({
  edges = EDGES.ALL,
  color = COLOR.TEAL,
  style = 'solid',
  width = 1
} = {}) => {
  const keys = parseEdges(edges)
  if (isArray(keys)) {
    if (keys.length === 4) {
      return {
        borderWidth: width,
        borderStyle: style,
        borderColor: color
      }
    } else {
      return arrayReduce(keys, (result, key) => {
        result[wrapKey(key, 'border', 'width')] = width
        result[wrapKey(key, 'border', 'style')] = style
        result[wrapKey(key, 'border', 'color')] = color
        return result
      }, {})
    }
  } else {
    throw new Error('invalid edges value')
  }
}
